[![@wq/router][logo]][docs]

**@wq/router** is a [wq.app] module that captures URL changes and "responds" with locally-rendered HTML pages.  @wq/router is primarily used with [@wq/app], a higher-level module that automatically registers the appropriate routes via the [wq configuration object][config].  @wq/router also supports direct route registration for routes that do not fit into @wq/app's conventions.  @wq/router is based on [Redux-First Router] and leverages similar concepts.

### [Documentation][docs]

[**Installation**][installation]
&bull;
[**API**][api]
&bull;
[Configuration][configuration]
&bull;
[Route Info][route-information]
&bull;
[**Plugins**][plugin-types]
&bull;
[**Methods**][methods]

[logo]: https://wq.io/images/@wq/router.svg
[docs]: https://wq.io/@wq/router
[installation]: https://wq.io/@wq/router#installation
[api]: https://wq.io/@wq/router#api
[configuration]: https://wq.io/@wq/router#configuration
[route-information]: https://wq.io/@wq/router#route-information
[plugin-types]: https://wq.io/@wq/router#plugin-types
[methods]: https://wq.io/@wq/router#methods

[wq.app]: https://wq.io/wq.app/
[@wq/app]: https://wq.io/@wq/app
[config]: https://wq.io/config

[Redux-First Router]: https://github.com/faceyspacey/redux-first-router
